import sys
import typing


def action_pushdown(channel_index: int = -1):
    '''Push action down onto the top of the NLA stack as a new strip 

    :param channel_index: Channel Index, Index of NLA action channel to perform pushdown operation on 
    :type channel_index: int
    '''

    pass


def action_sync_length(active: bool = True):
    '''Synchronize the length of the referenced Action with the length used in the strip 

    :param active: Active Strip Only, Only sync the active length for the active strip 
    :type active: bool
    '''

    pass


def action_unlink(force_delete: bool = False):
    '''Unlink this action from the active action slot (and/or exit Tweak Mode) 

    :param force_delete: Force Delete, Clear Fake User and remove copy stashed in this datablock’s NLA stack 
    :type force_delete: bool
    '''

    pass


def actionclip_add(action: typing.Union[int, str] = ''):
    '''Add an Action-Clip strip (i.e. an NLA Strip referencing an Action) to the active track 

    :param action: Action 
    :type action: typing.Union[int, str]
    '''

    pass


def apply_scale():
    '''Apply scaling of selected strips to their referenced Actions 

    '''

    pass


def bake(frame_start: int = 1,
         frame_end: int = 250,
         step: int = 1,
         only_selected: bool = True,
         visual_keying: bool = False,
         clear_constraints: bool = False,
         clear_parents: bool = False,
         use_current_action: bool = False,
         bake_types: typing.Set[typing.Union[int, str]] = {'POSE'}):
    '''Bake all selected objects loc/scale/rotation animation to an action 

    :param frame_start: Start Frame, Start frame for baking 
    :type frame_start: int
    :param frame_end: End Frame, End frame for baking 
    :type frame_end: int
    :param step: Frame Step, Frame Step 
    :type step: int
    :param only_selected: Only Selected Bones, Only key selected bones (Pose baking only) 
    :type only_selected: bool
    :param visual_keying: Visual Keying, Keyframe from the final transformations (with constraints applied) 
    :type visual_keying: bool
    :param clear_constraints: Clear Constraints, Remove all constraints from keyed object/bones, and do ‘visual’ keying 
    :type clear_constraints: bool
    :param clear_parents: Clear Parents, Bake animation onto the object then clear parents (objects only) 
    :type clear_parents: bool
    :param use_current_action: Overwrite Current Action, Bake animation into current action, instead of creating a new one (useful for baking only part of bones in an armature) 
    :type use_current_action: bool
    :param bake_types: Bake Data, Which data’s transformations to bakePOSE Pose, Bake bones transformations.OBJECT Object, Bake object transformations. 
    :type bake_types: typing.Set[typing.Union[int, str]]
    '''

    pass


def channels_click(extend: bool = False):
    '''Handle clicks to select NLA channels 

    :param extend: Extend Select 
    :type extend: bool
    '''

    pass


def clear_scale():
    '''Reset scaling of selected strips 

    '''

    pass


def click_select(extend: bool = False, deselect_all: bool = False):
    '''Handle clicks to select NLA Strips 

    :param extend: Extend Select 
    :type extend: bool
    :param deselect_all: Deselect On Nothing, Deselect all when nothing under the cursor 
    :type deselect_all: bool
    '''

    pass


def delete():
    '''Delete selected strips 

    '''

    pass


def duplicate(linked: bool = False,
              mode: typing.Union[int, str] = 'TRANSLATION'):
    '''Duplicate selected NLA-Strips, adding the new strips in new tracks above the originals 

    :param linked: Linked, When duplicating strips, assign new copies of the actions they use 
    :type linked: bool
    :param mode: Mode 
    :type mode: typing.Union[int, str]
    '''

    pass


def fmodifier_add(type: typing.Union[int, str] = 'NULL',
                  only_active: bool = True):
    '''Add F-Modifier to the active/selected NLA-Strips 

    :param type: TypeNULL Invalid.GENERATOR Generator, Generate a curve using a factorized or expanded polynomial.FNGENERATOR Built-In Function, Generate a curve using standard math functions such as sin and cos.ENVELOPE Envelope, Reshape F-Curve values - e.g. change amplitude of movements.CYCLES Cycles, Cyclic extend/repeat keyframe sequence.NOISE Noise, Add pseudo-random noise on top of F-Curves.LIMITS Limits, Restrict maximum and minimum values of F-Curve.STEPPED Stepped Interpolation, Snap values to nearest grid-step - e.g. for a stop-motion look. 
    :type type: typing.Union[int, str]
    :param only_active: Only Active, Only add a F-Modifier of the specified type to the active strip 
    :type only_active: bool
    '''

    pass


def fmodifier_copy():
    '''Copy the F-Modifier(s) of the active NLA-Strip 

    '''

    pass


def fmodifier_paste(only_active: bool = True, replace: bool = False):
    '''Add copied F-Modifiers to the selected NLA-Strips 

    :param only_active: Only Active, Only paste F-Modifiers on active strip 
    :type only_active: bool
    :param replace: Replace Existing, Replace existing F-Modifiers, instead of just appending to the end of the existing list 
    :type replace: bool
    '''

    pass


def make_single_user():
    '''Ensure that each action is only used once in the set of strips selected 

    '''

    pass


def meta_add():
    '''Add new meta-strips incorporating the selected strips 

    '''

    pass


def meta_remove():
    '''Separate out the strips held by the selected meta-strips 

    '''

    pass


def move_down():
    '''Move selected strips down a track if there’s room 

    '''

    pass


def move_up():
    '''Move selected strips up a track if there’s room 

    '''

    pass


def mute_toggle():
    '''Mute or un-mute selected strips 

    '''

    pass


def previewrange_set():
    '''Automatically set Preview Range based on range of keyframes 

    '''

    pass


def select_all(action: typing.Union[int, str] = 'TOGGLE'):
    '''Select or deselect all NLA-Strips 

    :param action: Action, Selection action to executeTOGGLE Toggle, Toggle selection for all elements.SELECT Select, Select all elements.DESELECT Deselect, Deselect all elements.INVERT Invert, Invert selection of all elements. 
    :type action: typing.Union[int, str]
    '''

    pass


def select_box(axis_range: bool = False,
               tweak: bool = False,
               xmin: int = 0,
               xmax: int = 0,
               ymin: int = 0,
               ymax: int = 0,
               wait_for_input: bool = True,
               mode: typing.Union[int, str] = 'SET'):
    '''Use box selection to grab NLA-Strips 

    :param axis_range: Axis Range 
    :type axis_range: bool
    :param tweak: Tweak, Operator has been activated using a tweak event 
    :type tweak: bool
    :param xmin: X Min 
    :type xmin: int
    :param xmax: X Max 
    :type xmax: int
    :param ymin: Y Min 
    :type ymin: int
    :param ymax: Y Max 
    :type ymax: int
    :param wait_for_input: Wait for Input 
    :type wait_for_input: bool
    :param mode: ModeSET Set, Set a new selection.ADD Extend, Extend existing selection.SUB Subtract, Subtract existing selection. 
    :type mode: typing.Union[int, str]
    '''

    pass


def select_leftright(mode: typing.Union[int, str] = 'CHECK',
                     extend: bool = False):
    '''Select strips to the left or the right of the current frame 

    :param mode: Mode 
    :type mode: typing.Union[int, str]
    :param extend: Extend Select 
    :type extend: bool
    '''

    pass


def selected_objects_add():
    '''Make selected objects appear in NLA Editor by adding Animation Data 

    '''

    pass


def snap(type: typing.Union[int, str] = 'CFRA'):
    '''Move start of strips to specified time 

    :param type: Type 
    :type type: typing.Union[int, str]
    '''

    pass


def soundclip_add():
    '''Add a strip for controlling when speaker plays its sound clip 

    '''

    pass


def split():
    '''Split selected strips at their midpoints 

    '''

    pass


def swap():
    '''Swap order of selected strips within tracks 

    '''

    pass


def tracks_add(above_selected: bool = False):
    '''Add NLA-Tracks above/after the selected tracks 

    :param above_selected: Above Selected, Add a new NLA Track above every existing selected one 
    :type above_selected: bool
    '''

    pass


def tracks_delete():
    '''Delete selected NLA-Tracks and the strips they contain 

    '''

    pass


def transition_add():
    '''Add a transition strip between two adjacent selected strips 

    '''

    pass


def tweakmode_enter(isolate_action: bool = False):
    '''Enter tweaking mode for the action referenced by the active strip to edit its keyframes 

    :param isolate_action: Isolate Action, Enable ‘solo’ on the NLA Track containing the active strip, to edit it without seeing the effects of the NLA stack 
    :type isolate_action: bool
    '''

    pass


def tweakmode_exit(isolate_action: bool = False):
    '''Exit tweaking mode for the action referenced by the active strip 

    :param isolate_action: Isolate Action, Disable ‘solo’ on any of the NLA Tracks after exiting tweak mode to get things back to normal 
    :type isolate_action: bool
    '''

    pass


def view_all():
    '''Reset viewable area to show full strips range 

    '''

    pass


def view_frame():
    '''Reset viewable area to show range around current frame 

    '''

    pass


def view_selected():
    '''Reset viewable area to show selected strips range 

    '''

    pass



import sys
import typing
import bpy


def active_frame_delete():
    '''Delete the active frame for the active Grease Pencil Layer 

    '''

    pass


def active_frames_delete_all():
    '''Delete the active frame(s) of all editable Grease Pencil layers 

    '''

    pass


def annotate(mode: typing.Union[int, str] = 'DRAW',
             stroke: typing.List['bpy.types.OperatorStrokeElement'] = None,
             wait_for_input: bool = True):
    '''Make annotations on the active data 

    :param mode: Mode, Way to interpret mouse movementsDRAW Draw Freehand, Draw freehand stroke(s).DRAW_STRAIGHT Draw Straight Lines, Draw straight line segment(s).DRAW_POLY Draw Poly Line, Click to place endpoints of straight line segments (connected).ERASER Eraser, Erase Annotation strokes. 
    :type mode: typing.Union[int, str]
    :param stroke: Stroke 
    :type stroke: typing.List['bpy.types.OperatorStrokeElement']
    :param wait_for_input: Wait for Input, Wait for first click instead of painting immediately 
    :type wait_for_input: bool
    '''

    pass


def blank_frame_add(all_layers: bool = False):
    '''Insert a blank frame on the current frame (all subsequently existing frames, if any, are shifted right by one frame) 

    :param all_layers: All Layers, Create blank frame in all layers, not only active 
    :type all_layers: bool
    '''

    pass


def brush_presets_create():
    '''Create a set of predefined Grease Pencil drawing brushes 

    '''

    pass


def color_hide(unselected: bool = False):
    '''Hide selected/unselected Grease Pencil colors 

    :param unselected: Unselected, Hide unselected rather than selected colors 
    :type unselected: bool
    '''

    pass


def color_isolate(affect_visibility: bool = False):
    '''Toggle whether the active color is the only one that is editable and/or visible 

    :param affect_visibility: Affect Visibility, In addition to toggling the editability, also affect the visibility 
    :type affect_visibility: bool
    '''

    pass


def color_lock_all():
    '''Lock all Grease Pencil colors to prevent them from being accidentally modified 

    '''

    pass


def color_reveal():
    '''Unhide all hidden Grease Pencil colors 

    '''

    pass


def color_select(deselect: bool = False):
    '''Select all Grease Pencil strokes using current color 

    :param deselect: Deselect, Unselect strokes 
    :type deselect: bool
    '''

    pass


def color_unlock_all():
    '''Unlock all Grease Pencil colors so that they can be edited 

    '''

    pass


def convert(type: typing.Union[int, str] = 'PATH',
            use_normalize_weights: bool = True,
            radius_multiplier: float = 1.0,
            use_link_strokes: bool = False,
            timing_mode: typing.Union[int, str] = 'FULL',
            frame_range: int = 100,
            start_frame: int = 1,
            use_realtime: bool = False,
            end_frame: int = 250,
            gap_duration: float = 0.0,
            gap_randomness: float = 0.0,
            seed: int = 0,
            use_timing_data: bool = False):
    '''Convert the active Grease Pencil layer to a new Curve Object 

    :param type: Type, Which type of curve to convert toPATH Path, Animation path.CURVE Bezier Curve, Smooth Bezier curve.POLY Polygon Curve, Bezier curve with straight-line segments (vector handles). 
    :type type: typing.Union[int, str]
    :param use_normalize_weights: Normalize Weight, Normalize weight (set from stroke width) 
    :type use_normalize_weights: bool
    :param radius_multiplier: Radius Fac, Multiplier for the points’ radii (set from stroke width) 
    :type radius_multiplier: float
    :param use_link_strokes: Link Strokes, Whether to link strokes with zero-radius sections of curves 
    :type use_link_strokes: bool
    :param timing_mode: Timing Mode, How to use timing data stored in strokesNONE No Timing, Ignore timing.LINEAR Linear, Simple linear timing.FULL Original, Use the original timing, gaps included.CUSTOMGAP Custom Gaps, Use the original timing, but with custom gap lengths (in frames). 
    :type timing_mode: typing.Union[int, str]
    :param frame_range: Frame Range, The duration of evaluation of the path control curve 
    :type frame_range: int
    :param start_frame: Start Frame, The start frame of the path control curve 
    :type start_frame: int
    :param use_realtime: Realtime, Whether the path control curve reproduces the drawing in realtime, starting from Start Frame 
    :type use_realtime: bool
    :param end_frame: End Frame, The end frame of the path control curve (if Realtime is not set) 
    :type end_frame: int
    :param gap_duration: Gap Duration, Custom Gap mode: (Average) length of gaps, in frames (Note: Realtime value, will be scaled if Realtime is not set) 
    :type gap_duration: float
    :param gap_randomness: Gap Randomness, Custom Gap mode: Number of frames that gap lengths can vary 
    :type gap_randomness: float
    :param seed: Random Seed, Custom Gap mode: Random generator seed 
    :type seed: int
    :param use_timing_data: Has Valid Timing, Whether the converted Grease Pencil layer has valid timing data (internal use) 
    :type use_timing_data: bool
    '''

    pass


def convert_old_files(annotation: bool = False):
    '''Convert 2.7x grease pencil files to 2.80 

    :param annotation: Annotation, Convert to Annotations 
    :type annotation: bool
    '''

    pass


def copy():
    '''Copy selected Grease Pencil points and strokes 

    '''

    pass


def data_add():
    '''Add new Grease Pencil data-block 

    '''

    pass


def data_unlink():
    '''Unlink active Annotation data-block 

    '''

    pass


def delete(type: typing.Union[int, str] = 'POINTS'):
    '''Delete selected Grease Pencil strokes, vertices, or frames 

    :param type: Type, Method used for deleting Grease Pencil dataPOINTS Points, Delete selected points and split strokes into segments.STROKES Strokes, Delete selected strokes.FRAME Frame, Delete active frame. 
    :type type: typing.Union[int, str]
    '''

    pass


def dissolve(type: typing.Union[int, str] = 'POINTS'):
    '''Delete selected points without splitting strokes 

    :param type: Type, Method used for dissolving Stroke pointsPOINTS Dissolve, Dissolve selected points.BETWEEN Dissolve Between, Dissolve points between selected points.UNSELECT Dissolve Unselect, Dissolve all unselected points. 
    :type type: typing.Union[int, str]
    '''

    pass


def draw(mode: typing.Union[int, str] = 'DRAW',
         stroke: typing.List['bpy.types.OperatorStrokeElement'] = None,
         wait_for_input: bool = True,
         disable_straight: bool = False,
         disable_fill: bool = False,
         guide_last_angle: float = 0.0):
    '''Draw a new stroke in the active Grease Pencil Object 

    :param mode: Mode, Way to interpret mouse movementsDRAW Draw Freehand, Draw freehand stroke(s).DRAW_STRAIGHT Draw Straight Lines, Draw straight line segment(s).DRAW_POLY Draw Poly Line, Click to place endpoints of straight line segments (connected).ERASER Eraser, Erase Grease Pencil strokes. 
    :type mode: typing.Union[int, str]
    :param stroke: Stroke 
    :type stroke: typing.List['bpy.types.OperatorStrokeElement']
    :param wait_for_input: Wait for Input, Wait for first click instead of painting immediately 
    :type wait_for_input: bool
    :param disable_straight: No Straight lines, Disable key for straight lines 
    :type disable_straight: bool
    :param disable_fill: No Fill Areas, Disable fill to use stroke as fill boundary 
    :type disable_fill: bool
    :param guide_last_angle: Angle, Speed guide angle 
    :type guide_last_angle: float
    '''

    pass


def duplicate():
    '''Duplicate the selected Grease Pencil strokes 

    '''

    pass


def duplicate_move(GPENCIL_OT_duplicate=None, TRANSFORM_OT_translate=None):
    '''Make copies of the selected Grease Pencil strokes and move them 

    :param GPENCIL_OT_duplicate: Duplicate Strokes, Duplicate the selected Grease Pencil strokes 
    :param TRANSFORM_OT_translate: Move, Move selected items 
    '''

    pass


def editmode_toggle(back: bool = False):
    '''Enter/Exit edit mode for Grease Pencil strokes 

    :param back: Return to Previous Mode, Return to previous mode 
    :type back: bool
    '''

    pass


def extrude():
    '''Extrude the selected Grease Pencil points 

    '''

    pass


def extrude_move(GPENCIL_OT_extrude=None, TRANSFORM_OT_translate=None):
    '''Extrude selected points and move them 

    :param GPENCIL_OT_extrude: Extrude Stroke Points, Extrude the selected Grease Pencil points 
    :param TRANSFORM_OT_translate: Move, Move selected items 
    '''

    pass


def fill(on_back: bool = False):
    '''Fill with color the shape formed by strokes 

    :param on_back: Draw On Back, Send new stroke to Back 
    :type on_back: bool
    '''

    pass


def frame_clean_fill(mode: typing.Union[int, str] = 'ACTIVE'):
    '''Remove ‘no fill’ boundary strokes 

    :param mode: ModeACTIVE Active Frame Only, Clean active frame only.ALL All Frames, Clean all frames in all layers. 
    :type mode: typing.Union[int, str]
    '''

    pass


def frame_clean_loose(limit: int = 1):
    '''Remove loose points 

    :param limit: Limit, Number of points to consider stroke as loose 
    :type limit: int
    '''

    pass


def frame_duplicate(mode: typing.Union[int, str] = 'ACTIVE'):
    '''Make a copy of the active Grease Pencil Frame 

    :param mode: ModeACTIVE Active, Duplicate frame in active layer only.ALL All, Duplicate active frames in all layers. 
    :type mode: typing.Union[int, str]
    '''

    pass


def generate_weights(mode: typing.Union[int, str] = 'NAME',
                     armature: typing.Union[int, str] = 'DEFAULT',
                     ratio: float = 0.1,
                     decay: float = 0.8):
    '''Generate automatic weights for armatures (requires armature modifier) 

    :param mode: Mode 
    :type mode: typing.Union[int, str]
    :param armature: Armature, Armature to use 
    :type armature: typing.Union[int, str]
    :param ratio: Ratio, Ratio between bone length and influence radius 
    :type ratio: float
    :param decay: Decay, Factor to reduce influence depending of distance to bone axis 
    :type decay: float
    '''

    pass


def guide_rotate(increment: bool = True, angle: float = 0.0):
    '''Rotate guide angle 

    :param increment: Increment, Increment angle 
    :type increment: bool
    :param angle: Angle, Guide angle 
    :type angle: float
    '''

    pass


def hide(unselected: bool = False):
    '''Hide selected/unselected Grease Pencil layers 

    :param unselected: Unselected, Hide unselected rather than selected layers 
    :type unselected: bool
    '''

    pass


def interpolate(shift: float = 0.0):
    '''Interpolate grease pencil strokes between frames 

    :param shift: Shift, Bias factor for which frame has more influence on the interpolated strokes 
    :type shift: float
    '''

    pass


def interpolate_reverse():
    '''Remove breakdown frames generated by interpolating between two Grease Pencil frames 

    '''

    pass


def interpolate_sequence():
    '''Generate ‘in-betweens’ to smoothly interpolate between Grease Pencil frames 

    '''

    pass


def layer_add():
    '''Add new layer or note for the active data-block 

    '''

    pass


def layer_change(layer: typing.Union[int, str] = 'DEFAULT'):
    '''Change active Grease Pencil layer 

    :param layer: Grease Pencil Layer 
    :type layer: typing.Union[int, str]
    '''

    pass


def layer_duplicate():
    '''Make a copy of the active Grease Pencil layer 

    '''

    pass


def layer_duplicate_object(object: str = "",
                           mode: typing.Union[int, str] = 'ALL'):
    '''Make a copy of the active Grease Pencil layer to new object 

    :param object: Object, Name of the destination object 
    :type object: str
    :param mode: Mode 
    :type mode: typing.Union[int, str]
    '''

    pass


def layer_isolate(affect_visibility: bool = False):
    '''Toggle whether the active layer is the only one that can be edited and/or visible 

    :param affect_visibility: Affect Visibility, In addition to toggling the editability, also affect the visibility 
    :type affect_visibility: bool
    '''

    pass


def layer_merge():
    '''Merge the current layer with the layer below 

    '''

    pass


def layer_move(type: typing.Union[int, str] = 'UP'):
    '''Move the active Grease Pencil layer up/down in the list 

    :param type: Type 
    :type type: typing.Union[int, str]
    '''

    pass


def layer_remove():
    '''Remove active Grease Pencil layer 

    '''

    pass


def lock_all():
    '''Lock all Grease Pencil layers to prevent them from being accidentally modified 

    '''

    pass


def lock_layer():
    '''Lock and hide any color not used in any layer 

    '''

    pass


def move_to_layer(layer: typing.Union[int, str] = 'DEFAULT'):
    '''Move selected strokes to another layer 

    :param layer: Grease Pencil Layer 
    :type layer: typing.Union[int, str]
    '''

    pass


def paintmode_toggle(back: bool = False):
    '''Enter/Exit paint mode for Grease Pencil strokes 

    :param back: Return to Previous Mode, Return to previous mode 
    :type back: bool
    '''

    pass


def paste(type: typing.Union[int, str] = 'COPY'):
    '''Paste previously copied strokes or copy and merge in active layer 

    :param type: Type 
    :type type: typing.Union[int, str]
    '''

    pass


def primitive(edges: int = 4,
              type: typing.Union[int, str] = 'BOX',
              wait_for_input: bool = True):
    '''Create predefined grease pencil stroke shapes 

    :param edges: Edges, Number of polygon edges 
    :type edges: int
    :param type: Type, Type of shape 
    :type type: typing.Union[int, str]
    :param wait_for_input: Wait for Input 
    :type wait_for_input: bool
    '''

    pass


def reproject(type: typing.Union[int, str] = 'VIEW'):
    '''Reproject the selected strokes from the current viewpoint as if they had been newly drawn (e.g. to fix problems from accidental 3D cursor movement or accidental viewport changes, or for matching deforming geometry) 

    :param type: Projection TypeFRONT Front, Reproject the strokes using the X-Z plane.SIDE Side, Reproject the strokes using the Y-Z plane.TOP Top, Reproject the strokes using the X-Y plane.VIEW View, Reproject the strokes to end up on the same plane, as if drawn from the current viewpoint using ‘Cursor’ Stroke Placement.SURFACE Surface, Reproject the strokes on to the scene geometry, as if drawn using ‘Surface’ placement.CURSOR Cursor, Reproject the strokes using the orienation of 3D cursor. 
    :type type: typing.Union[int, str]
    '''

    pass


def reveal(select: bool = True):
    '''Show all Grease Pencil layers 

    :param select: Select 
    :type select: bool
    '''

    pass


def sculpt_paint(stroke: typing.List['bpy.types.OperatorStrokeElement'] = None,
                 wait_for_input: bool = True):
    '''Apply tweaks to strokes by painting over the strokes 

    :param stroke: Stroke 
    :type stroke: typing.List['bpy.types.OperatorStrokeElement']
    :param wait_for_input: Wait for Input, Enter a mini ‘sculpt-mode’ if enabled, otherwise, exit after drawing a single stroke 
    :type wait_for_input: bool
    '''

    pass


def sculptmode_toggle(back: bool = False):
    '''Enter/Exit sculpt mode for Grease Pencil strokes 

    :param back: Return to Previous Mode, Return to previous mode 
    :type back: bool
    '''

    pass


def select(extend: bool = False,
           deselect: bool = False,
           toggle: bool = False,
           deselect_all: bool = False,
           entire_strokes: bool = False,
           location: int = (0, 0)):
    '''Select Grease Pencil strokes and/or stroke points 

    :param extend: Extend, Extend selection instead of deselecting everything first 
    :type extend: bool
    :param deselect: Deselect, Remove from selection 
    :type deselect: bool
    :param toggle: Toggle Selection, Toggle the selection 
    :type toggle: bool
    :param deselect_all: Deselect On Nothing, Deselect all when nothing under the cursor 
    :type deselect_all: bool
    :param entire_strokes: Entire Strokes, Select entire strokes instead of just the nearest stroke vertex 
    :type entire_strokes: bool
    :param location: Location, Mouse location 
    :type location: int
    '''

    pass


def select_all(action: typing.Union[int, str] = 'TOGGLE'):
    '''Change selection of all Grease Pencil strokes currently visible 

    :param action: Action, Selection action to executeTOGGLE Toggle, Toggle selection for all elements.SELECT Select, Select all elements.DESELECT Deselect, Deselect all elements.INVERT Invert, Invert selection of all elements. 
    :type action: typing.Union[int, str]
    '''

    pass


def select_alternate(unselect_ends: bool = True):
    '''Select alternative points in same strokes as already selected points 

    :param unselect_ends: Unselect Ends, Do not select the first and last point of the stroke 
    :type unselect_ends: bool
    '''

    pass


def select_box(xmin: int = 0,
               xmax: int = 0,
               ymin: int = 0,
               ymax: int = 0,
               wait_for_input: bool = True,
               mode: typing.Union[int, str] = 'SET'):
    '''Select Grease Pencil strokes within a rectangular region 

    :param xmin: X Min 
    :type xmin: int
    :param xmax: X Max 
    :type xmax: int
    :param ymin: Y Min 
    :type ymin: int
    :param ymax: Y Max 
    :type ymax: int
    :param wait_for_input: Wait for Input 
    :type wait_for_input: bool
    :param mode: ModeSET Set, Set a new selection.ADD Extend, Extend existing selection.SUB Subtract, Subtract existing selection.XOR Difference, Inverts existing selection.AND Intersect, Intersect existing selection. 
    :type mode: typing.Union[int, str]
    '''

    pass


def select_circle(x: int = 0,
                  y: int = 0,
                  radius: int = 25,
                  wait_for_input: bool = True,
                  mode: typing.Union[int, str] = 'SET'):
    '''Select Grease Pencil strokes using brush selection 

    :param x: X 
    :type x: int
    :param y: Y 
    :type y: int
    :param radius: Radius 
    :type radius: int
    :param wait_for_input: Wait for Input 
    :type wait_for_input: bool
    :param mode: ModeSET Set, Set a new selection.ADD Extend, Extend existing selection.SUB Subtract, Subtract existing selection. 
    :type mode: typing.Union[int, str]
    '''

    pass


def select_first(only_selected_strokes: bool = False, extend: bool = False):
    '''Select first point in Grease Pencil strokes 

    :param only_selected_strokes: Selected Strokes Only, Only select the first point of strokes that already have points selected 
    :type only_selected_strokes: bool
    :param extend: Extend, Extend selection instead of deselecting all other selected points 
    :type extend: bool
    '''

    pass


def select_grouped(type: typing.Union[int, str] = 'LAYER'):
    '''Select all strokes with similar characteristics 

    :param type: TypeLAYER Layer, Shared layers.MATERIAL Material, Shared materials. 
    :type type: typing.Union[int, str]
    '''

    pass


def select_lasso(mode: typing.Union[int, str] = 'SET',
                 path: typing.List['bpy.types.OperatorMousePath'] = None):
    '''Select Grease Pencil strokes using lasso selection 

    :param mode: ModeSET Set, Set a new selection.ADD Extend, Extend existing selection.SUB Subtract, Subtract existing selection.XOR Difference, Inverts existing selection.AND Intersect, Intersect existing selection. 
    :type mode: typing.Union[int, str]
    :param path: Path 
    :type path: typing.List['bpy.types.OperatorMousePath']
    '''

    pass


def select_last(only_selected_strokes: bool = False, extend: bool = False):
    '''Select last point in Grease Pencil strokes 

    :param only_selected_strokes: Selected Strokes Only, Only select the last point of strokes that already have points selected 
    :type only_selected_strokes: bool
    :param extend: Extend, Extend selection instead of deselecting all other selected points 
    :type extend: bool
    '''

    pass


def select_less():
    '''Shrink sets of selected Grease Pencil points 

    '''

    pass


def select_linked():
    '''Select all points in same strokes as already selected points 

    '''

    pass


def select_more():
    '''Grow sets of selected Grease Pencil points 

    '''

    pass


def selection_opacity_toggle():
    '''Hide/Unhide selected points for Grease Pencil strokes setting alpha factor 

    '''

    pass


def selectmode_toggle(mode: int = 0):
    '''Set selection mode for Grease Pencil strokes 

    :param mode: Select mode, Select mode 
    :type mode: int
    '''

    pass


def snap_cursor_to_selected():
    '''Snap cursor to center of selected points 

    '''

    pass


def snap_to_cursor(use_offset: bool = True):
    '''Snap selected points/strokes to the cursor 

    :param use_offset: With Offset, Offset the entire stroke instead of selected points only 
    :type use_offset: bool
    '''

    pass


def snap_to_grid():
    '''Snap selected points to the nearest grid points 

    '''

    pass


def stroke_apply_thickness():
    '''Apply the thickness change of the layer to its strokes 

    '''

    pass


def stroke_arrange(direction: typing.Union[int, str] = 'UP'):
    '''Arrange selected strokes up/down in the drawing order of the active layer 

    :param direction: Direction 
    :type direction: typing.Union[int, str]
    '''

    pass


def stroke_caps_set(type: typing.Union[int, str] = 'TOGGLE'):
    '''Change Stroke caps mode (rounded or flat) 

    :param type: TypeTOGGLE Both.START Start.END End.TOGGLE Default, Set as default rounded. 
    :type type: typing.Union[int, str]
    '''

    pass


def stroke_change_color(material: str = ""):
    '''Move selected strokes to active material 

    :param material: Material, Name of the material 
    :type material: str
    '''

    pass


def stroke_cutter(path: typing.List['bpy.types.OperatorMousePath'] = None):
    '''Select section and cut 

    :param path: Path 
    :type path: typing.List['bpy.types.OperatorMousePath']
    '''

    pass


def stroke_cyclical_set(type: typing.Union[int, str] = 'TOGGLE',
                        geometry: bool = False):
    '''Close or open the selected stroke adding an edge from last to first point 

    :param type: Type 
    :type type: typing.Union[int, str]
    :param geometry: Create Geometry, Create new geometry for closing stroke 
    :type geometry: bool
    '''

    pass


def stroke_flip():
    '''Change direction of the points of the selected strokes 

    '''

    pass


def stroke_join(type: typing.Union[int, str] = 'JOIN',
                leave_gaps: bool = False):
    '''Join selected strokes (optionally as new stroke) 

    :param type: Type 
    :type type: typing.Union[int, str]
    :param leave_gaps: Leave Gaps, Leave gaps between joined strokes instead of linking them 
    :type leave_gaps: bool
    '''

    pass


def stroke_lock_color():
    '''Lock any color not used in any selected stroke 

    '''

    pass


def stroke_merge(mode: typing.Union[int, str] = 'STROKE',
                 back: bool = False,
                 additive: bool = False,
                 cyclic: bool = False,
                 clear_point: bool = False,
                 clear_stroke: bool = False):
    '''Create a new stroke with the selected stroke points 

    :param mode: Mode 
    :type mode: typing.Union[int, str]
    :param back: Draw on Back, Draw new stroke below all previous strokes 
    :type back: bool
    :param additive: Additive Drawing, Add to previous drawing 
    :type additive: bool
    :param cyclic: Cyclic, Close new stroke 
    :type cyclic: bool
    :param clear_point: Dissolve Points, Dissolve old selected points 
    :type clear_point: bool
    :param clear_stroke: Delete Strokes, Delete old selected strokes 
    :type clear_stroke: bool
    '''

    pass


def stroke_separate(mode: typing.Union[int, str] = 'POINT'):
    '''Separate the selected strokes or layer in a new grease pencil object 

    :param mode: ModePOINT Selected Points, Separate the selected points.STROKE Selected Strokes, Separate the selected strokes.LAYER Active Layer, Separate the strokes of the current layer. 
    :type mode: typing.Union[int, str]
    '''

    pass


def stroke_simplify(factor: float = 0.0):
    '''Simplify selected stroked reducing number of points 

    :param factor: Factor 
    :type factor: float
    '''

    pass


def stroke_simplify_fixed(step: int = 1):
    '''Simplify selected stroked reducing number of points using fixed algorithm 

    :param step: Steps, Number of simplify steps 
    :type step: int
    '''

    pass


def stroke_smooth(repeat: int = 1,
                  factor: float = 0.5,
                  only_selected: bool = True,
                  smooth_position: bool = True,
                  smooth_thickness: bool = True,
                  smooth_strength: bool = False,
                  smooth_uv: bool = False):
    '''Smooth selected strokes 

    :param repeat: Repeat 
    :type repeat: int
    :param factor: Factor 
    :type factor: float
    :param only_selected: Selected Points, Smooth only selected points in the stroke 
    :type only_selected: bool
    :param smooth_position: Position 
    :type smooth_position: bool
    :param smooth_thickness: Thickness 
    :type smooth_thickness: bool
    :param smooth_strength: Strength 
    :type smooth_strength: bool
    :param smooth_uv: UV 
    :type smooth_uv: bool
    '''

    pass


def stroke_split():
    '''Split selected points as new stroke on same frame 

    '''

    pass


def stroke_subdivide(number_cuts: int = 1,
                     factor: float = 0.0,
                     repeat: int = 1,
                     only_selected: bool = True,
                     smooth_position: bool = True,
                     smooth_thickness: bool = True,
                     smooth_strength: bool = False,
                     smooth_uv: bool = False):
    '''Subdivide between continuous selected points of the stroke adding a point half way between them 

    :param number_cuts: Number of Cuts 
    :type number_cuts: int
    :param factor: Smooth 
    :type factor: float
    :param repeat: Repeat 
    :type repeat: int
    :param only_selected: Selected Points, Smooth only selected points in the stroke 
    :type only_selected: bool
    :param smooth_position: Position 
    :type smooth_position: bool
    :param smooth_thickness: Thickness 
    :type smooth_thickness: bool
    :param smooth_strength: Strength 
    :type smooth_strength: bool
    :param smooth_uv: UV 
    :type smooth_uv: bool
    '''

    pass


def stroke_trim():
    '''Trim selected stroke to first loop or intersection 

    '''

    pass


def unlock_all():
    '''Unlock all Grease Pencil layers so that they can be edited 

    '''

    pass


def vertex_group_assign():
    '''Assign the selected vertices to the active vertex group 

    '''

    pass


def vertex_group_deselect():
    '''Deselect all selected vertices assigned to the active vertex group 

    '''

    pass


def vertex_group_invert():
    '''Invert weights to the active vertex group 

    '''

    pass


def vertex_group_normalize():
    '''Normalize weights to the active vertex group 

    '''

    pass


def vertex_group_normalize_all(lock_active: bool = True):
    '''Normalize all weights of all vertex groups, so that for each vertex, the sum of all weights is 1.0 

    :param lock_active: Lock Active, Keep the values of the active group while normalizing others 
    :type lock_active: bool
    '''

    pass


def vertex_group_remove_from():
    '''Remove the selected vertices from active or all vertex group(s) 

    '''

    pass


def vertex_group_select():
    '''Select all the vertices assigned to the active vertex group 

    '''

    pass


def vertex_group_smooth(factor: float = 0.5, repeat: int = 1):
    '''Smooth weights to the active vertex group 

    :param factor: Factor 
    :type factor: float
    :param repeat: Iterations 
    :type repeat: int
    '''

    pass


def weightmode_toggle(back: bool = False):
    '''Enter/Exit weight paint mode for Grease Pencil strokes 

    :param back: Return to Previous Mode, Return to previous mode 
    :type back: bool
    '''

    pass



import sys
import typing


def code_from_builtin(shader_name: str) -> dict:
    '''Exposes the internal shader code for query. 

    :param shader_name: One of these builtin shader names: { ‘2D_UNIFORM_COLOR’, ‘2D_FLAT_COLOR’, ‘2D_SMOOTH_COLOR’, ‘2D_IMAGE’, ‘3D_UNIFORM_COLOR’, ‘3D_FLAT_COLOR’, ‘3D_SMOOTH_COLOR’} 
    :type shader_name: str
    :return:  Vertex, fragment and geometry shader codes. 
    '''

    pass


def from_builtin(shader_name: str):
    '''Shaders that are embedded in the blender internal code. They all read the uniform ‘mat4 ModelViewProjectionMatrix’, which can be edited by the ‘gpu.matrix’ module. For more details, you can check the shader code with the function ‘gpu.shader.code_from_builtin’; 

    :param shader_name: One of these builtin shader names: { ‘2D_UNIFORM_COLOR’, ‘2D_FLAT_COLOR’, ‘2D_SMOOTH_COLOR’, ‘2D_IMAGE’, ‘3D_UNIFORM_COLOR’, ‘3D_FLAT_COLOR’, ‘3D_SMOOTH_COLOR’} 
    :type shader_name: str
    :return:  Shader object corresponding to the given name. 
    '''

    pass


def unbind():
    '''Unbind the bound shader object. 

    '''

    pass



import sys
import typing


def armature_apply(selected: bool = False):
    '''Apply the current pose as the new rest pose 

    :param selected: Selected Only, Only apply the selected bones (with propagation to children) 
    :type selected: bool
    '''

    pass


def autoside_names(axis: typing.Union[int, str] = 'XAXIS'):
    '''Automatically renames the selected bones according to which side of the target axis they fall on 

    :param axis: Axis, Axis tag names withXAXIS X-Axis, Left/Right.YAXIS Y-Axis, Front/Back.ZAXIS Z-Axis, Top/Bottom. 
    :type axis: typing.Union[int, str]
    '''

    pass


def bone_layers(
        layers: bool = (False, False, False, False, False, False, False, False,
                        False, False, False, False, False, False, False, False,
                        False, False, False, False, False, False, False, False,
                        False, False, False, False, False, False, False,
                        False)):
    '''Change the layers that the selected bones belong to 

    :param layers: Layer, Armature layers that bone belongs to 
    :type layers: bool
    '''

    pass


def breakdown(percentage: float = 0.5,
              prev_frame: int = 0,
              next_frame: int = 0,
              channels: typing.Union[int, str] = 'ALL',
              axis_lock: typing.Union[int, str] = 'FREE'):
    '''Create a suitable breakdown pose on the current frame 

    :param percentage: Percentage, Weighting factor for which keyframe is favored more 
    :type percentage: float
    :param prev_frame: Previous Keyframe, Frame number of keyframe immediately before the current frame 
    :type prev_frame: int
    :param next_frame: Next Keyframe, Frame number of keyframe immediately after the current frame 
    :type next_frame: int
    :param channels: Channels, Set of properties that are affectedALL All Properties, All properties, including transforms, bendy bone shape, and custom properties.LOC Location, Location only.ROT Rotation, Rotation only.SIZE Scale, Scale only.BBONE Bendy Bone, Bendy Bone shape properties.CUSTOM Custom Properties, Custom properties. 
    :type channels: typing.Union[int, str]
    :param axis_lock: Axis Lock, Transform axis to restrict effects toFREE Free, All axes are affected.X X, Only X-axis transforms are affected.Y Y, Only Y-axis transforms are affected.Z Z, Only Z-axis transforms are affected. 
    :type axis_lock: typing.Union[int, str]
    '''

    pass


def constraint_add(type: typing.Union[int, str] = ''):
    '''Add a constraint to the active bone 

    :param type: TypeCAMERA_SOLVER Camera Solver.FOLLOW_TRACK Follow Track.OBJECT_SOLVER Object Solver.COPY_LOCATION Copy Location, Copy the location of a target (with an optional offset), so that they move together.COPY_ROTATION Copy Rotation, Copy the rotation of a target (with an optional offset), so that they rotate together.COPY_SCALE Copy Scale, Copy the scale factors of a target (with an optional offset), so that they are scaled by the same amount.COPY_TRANSFORMS Copy Transforms, Copy all the transformations of a target, so that they move together.LIMIT_DISTANCE Limit Distance, Restrict movements to within a certain distance of a target (at the time of constraint evaluation only).LIMIT_LOCATION Limit Location, Restrict movement along each axis within given ranges.LIMIT_ROTATION Limit Rotation, Restrict rotation along each axis within given ranges.LIMIT_SCALE Limit Scale, Restrict scaling along each axis with given ranges.MAINTAIN_VOLUME Maintain Volume, Compensate for scaling one axis by applying suitable scaling to the other two axes.TRANSFORM Transformation, Use one transform property from target to control another (or same) property on owner.TRANSFORM_CACHE Transform Cache, Look up the transformation matrix from an external file.CLAMP_TO Clamp To, Restrict movements to lie along a curve by remapping location along curve’s longest axis.DAMPED_TRACK Damped Track, Point towards a target by performing the smallest rotation necessary.IK Inverse Kinematics, Control a chain of bones by specifying the endpoint target (Bones only).LOCKED_TRACK Locked Track, Rotate around the specified (‘locked’) axis to point towards a target.SPLINE_IK Spline IK, Align chain of bones along a curve (Bones only).STRETCH_TO Stretch To, Stretch along Y-Axis to point towards a target.TRACK_TO Track To, Legacy tracking constraint prone to twisting artifacts.ACTION Action, Use transform property of target to look up pose for owner from an Action.ARMATURE Armature, Apply weight-blended transformation from multiple bones like the Armature modifier.CHILD_OF Child Of, Make target the ‘detachable’ parent of owner.FLOOR Floor, Use position (and optionally rotation) of target to define a ‘wall’ or ‘floor’ that the owner can not cross.FOLLOW_PATH Follow Path, Use to animate an object/bone following a path.PIVOT Pivot, Change pivot point for transforms (buggy).SHRINKWRAP Shrinkwrap, Restrict movements to surface of target mesh. 
    :type type: typing.Union[int, str]
    '''

    pass


def constraint_add_with_targets(type: typing.Union[int, str] = ''):
    '''Add a constraint to the active bone, with target (where applicable) set to the selected Objects/Bones 

    :param type: TypeCAMERA_SOLVER Camera Solver.FOLLOW_TRACK Follow Track.OBJECT_SOLVER Object Solver.COPY_LOCATION Copy Location, Copy the location of a target (with an optional offset), so that they move together.COPY_ROTATION Copy Rotation, Copy the rotation of a target (with an optional offset), so that they rotate together.COPY_SCALE Copy Scale, Copy the scale factors of a target (with an optional offset), so that they are scaled by the same amount.COPY_TRANSFORMS Copy Transforms, Copy all the transformations of a target, so that they move together.LIMIT_DISTANCE Limit Distance, Restrict movements to within a certain distance of a target (at the time of constraint evaluation only).LIMIT_LOCATION Limit Location, Restrict movement along each axis within given ranges.LIMIT_ROTATION Limit Rotation, Restrict rotation along each axis within given ranges.LIMIT_SCALE Limit Scale, Restrict scaling along each axis with given ranges.MAINTAIN_VOLUME Maintain Volume, Compensate for scaling one axis by applying suitable scaling to the other two axes.TRANSFORM Transformation, Use one transform property from target to control another (or same) property on owner.TRANSFORM_CACHE Transform Cache, Look up the transformation matrix from an external file.CLAMP_TO Clamp To, Restrict movements to lie along a curve by remapping location along curve’s longest axis.DAMPED_TRACK Damped Track, Point towards a target by performing the smallest rotation necessary.IK Inverse Kinematics, Control a chain of bones by specifying the endpoint target (Bones only).LOCKED_TRACK Locked Track, Rotate around the specified (‘locked’) axis to point towards a target.SPLINE_IK Spline IK, Align chain of bones along a curve (Bones only).STRETCH_TO Stretch To, Stretch along Y-Axis to point towards a target.TRACK_TO Track To, Legacy tracking constraint prone to twisting artifacts.ACTION Action, Use transform property of target to look up pose for owner from an Action.ARMATURE Armature, Apply weight-blended transformation from multiple bones like the Armature modifier.CHILD_OF Child Of, Make target the ‘detachable’ parent of owner.FLOOR Floor, Use position (and optionally rotation) of target to define a ‘wall’ or ‘floor’ that the owner can not cross.FOLLOW_PATH Follow Path, Use to animate an object/bone following a path.PIVOT Pivot, Change pivot point for transforms (buggy).SHRINKWRAP Shrinkwrap, Restrict movements to surface of target mesh. 
    :type type: typing.Union[int, str]
    '''

    pass


def constraints_clear():
    '''Clear all the constraints for the selected bones 

    '''

    pass


def constraints_copy():
    '''Copy constraints to other selected bones 

    '''

    pass


def copy():
    '''Copies the current pose of the selected bones to copy/paste buffer 

    '''

    pass


def flip_names(do_strip_numbers: bool = False):
    '''Flips (and corrects) the axis suffixes of the names of selected bones 

    :param do_strip_numbers: Strip Numbers, Try to remove right-most dot-number from flipped names (WARNING: may result in incoherent naming in some cases) 
    :type do_strip_numbers: bool
    '''

    pass


def group_add():
    '''Add a new bone group 

    '''

    pass


def group_assign(type: int = 0):
    '''Add selected bones to the chosen bone group 

    :param type: Bone Group Index 
    :type type: int
    '''

    pass


def group_deselect():
    '''Deselect bones of active Bone Group 

    '''

    pass


def group_move(direction: typing.Union[int, str] = 'UP'):
    '''Change position of active Bone Group in list of Bone Groups 

    :param direction: Direction, Direction to move the active Bone Group towards 
    :type direction: typing.Union[int, str]
    '''

    pass


def group_remove():
    '''Remove the active bone group 

    '''

    pass


def group_select():
    '''Select bones in active Bone Group 

    '''

    pass


def group_sort():
    '''Sort Bone Groups by their names in ascending order 

    '''

    pass


def group_unassign():
    '''Remove selected bones from all bone groups 

    '''

    pass


def hide(unselected: bool = False):
    '''Tag selected bones to not be visible in Pose Mode 

    :param unselected: Unselected 
    :type unselected: bool
    '''

    pass


def ik_add(with_targets: bool = True):
    '''Add IK Constraint to the active Bone 

    :param with_targets: With Targets, Assign IK Constraint with targets derived from the select bones/objects 
    :type with_targets: bool
    '''

    pass


def ik_clear():
    '''Remove all IK Constraints from selected bones 

    '''

    pass


def loc_clear():
    '''Reset locations of selected bones to their default values 

    '''

    pass


def paste(flipped: bool = False, selected_mask: bool = False):
    '''Paste the stored pose on to the current pose 

    :param flipped: Flipped on X-Axis, Paste the stored pose flipped on to current pose 
    :type flipped: bool
    :param selected_mask: On Selected Only, Only paste the stored pose on to selected bones in the current pose 
    :type selected_mask: bool
    '''

    pass


def paths_calculate(start_frame: int = 1,
                    end_frame: int = 250,
                    bake_location: typing.Union[int, str] = 'HEADS'):
    '''Calculate paths for the selected bones 

    :param start_frame: Start, First frame to calculate bone paths on 
    :type start_frame: int
    :param end_frame: End, Last frame to calculate bone paths on 
    :type end_frame: int
    :param bake_location: Bake Location, Which point on the bones is used when calculating pathsHEADS Heads, Calculate bone paths from heads.TAILS Tails, Calculate bone paths from tails. 
    :type bake_location: typing.Union[int, str]
    '''

    pass


def paths_clear(only_selected: bool = False):
    '''Clear path caches for all bones, hold Shift key for selected bones only 

    :param only_selected: Only Selected, Only clear paths from selected bones 
    :type only_selected: bool
    '''

    pass


def paths_range_update():
    '''Update frame range for motion paths from the Scene’s current frame range 

    '''

    pass


def paths_update():
    '''Recalculate paths for bones that already have them 

    '''

    pass


def propagate(mode: typing.Union[int, str] = 'WHILE_HELD',
              end_frame: float = 250.0):
    '''Copy selected aspects of the current pose to subsequent poses already keyframed 

    :param mode: Terminate Mode, Method used to determine when to stop propagating pose to keyframesWHILE_HELD While Held, Propagate pose to all keyframes after current frame that don’t change (Default behavior).NEXT_KEY To Next Keyframe, Propagate pose to first keyframe following the current frame only.LAST_KEY To Last Keyframe, Propagate pose to the last keyframe only (i.e. making action cyclic).BEFORE_FRAME Before Frame, Propagate pose to all keyframes between current frame and ‘Frame’ property.BEFORE_END Before Last Keyframe, Propagate pose to all keyframes from current frame until no more are found.SELECTED_KEYS On Selected Keyframes, Propagate pose to all selected keyframes.SELECTED_MARKERS On Selected Markers, Propagate pose to all keyframes occurring on frames with Scene Markers after the current frame. 
    :type mode: typing.Union[int, str]
    :param end_frame: End Frame, Frame to stop propagating frames to (for ‘Before Frame’ mode) 
    :type end_frame: float
    '''

    pass


def push(percentage: float = 0.5,
         prev_frame: int = 0,
         next_frame: int = 0,
         channels: typing.Union[int, str] = 'ALL',
         axis_lock: typing.Union[int, str] = 'FREE'):
    '''Exaggerate the current pose in regards to the breakdown pose 

    :param percentage: Percentage, Weighting factor for which keyframe is favored more 
    :type percentage: float
    :param prev_frame: Previous Keyframe, Frame number of keyframe immediately before the current frame 
    :type prev_frame: int
    :param next_frame: Next Keyframe, Frame number of keyframe immediately after the current frame 
    :type next_frame: int
    :param channels: Channels, Set of properties that are affectedALL All Properties, All properties, including transforms, bendy bone shape, and custom properties.LOC Location, Location only.ROT Rotation, Rotation only.SIZE Scale, Scale only.BBONE Bendy Bone, Bendy Bone shape properties.CUSTOM Custom Properties, Custom properties. 
    :type channels: typing.Union[int, str]
    :param axis_lock: Axis Lock, Transform axis to restrict effects toFREE Free, All axes are affected.X X, Only X-axis transforms are affected.Y Y, Only Y-axis transforms are affected.Z Z, Only Z-axis transforms are affected. 
    :type axis_lock: typing.Union[int, str]
    '''

    pass


def push_rest(percentage: float = 0.5,
              prev_frame: int = 0,
              next_frame: int = 0,
              channels: typing.Union[int, str] = 'ALL',
              axis_lock: typing.Union[int, str] = 'FREE'):
    '''Push the current pose further away from the rest pose 

    :param percentage: Percentage, Weighting factor for which keyframe is favored more 
    :type percentage: float
    :param prev_frame: Previous Keyframe, Frame number of keyframe immediately before the current frame 
    :type prev_frame: int
    :param next_frame: Next Keyframe, Frame number of keyframe immediately after the current frame 
    :type next_frame: int
    :param channels: Channels, Set of properties that are affectedALL All Properties, All properties, including transforms, bendy bone shape, and custom properties.LOC Location, Location only.ROT Rotation, Rotation only.SIZE Scale, Scale only.BBONE Bendy Bone, Bendy Bone shape properties.CUSTOM Custom Properties, Custom properties. 
    :type channels: typing.Union[int, str]
    :param axis_lock: Axis Lock, Transform axis to restrict effects toFREE Free, All axes are affected.X X, Only X-axis transforms are affected.Y Y, Only Y-axis transforms are affected.Z Z, Only Z-axis transforms are affected. 
    :type axis_lock: typing.Union[int, str]
    '''

    pass


def quaternions_flip():
    '''Flip quaternion values to achieve desired rotations, while maintaining the same orientations 

    '''

    pass


def relax(percentage: float = 0.5,
          prev_frame: int = 0,
          next_frame: int = 0,
          channels: typing.Union[int, str] = 'ALL',
          axis_lock: typing.Union[int, str] = 'FREE'):
    '''Make the current pose more similar to its breakdown pose 

    :param percentage: Percentage, Weighting factor for which keyframe is favored more 
    :type percentage: float
    :param prev_frame: Previous Keyframe, Frame number of keyframe immediately before the current frame 
    :type prev_frame: int
    :param next_frame: Next Keyframe, Frame number of keyframe immediately after the current frame 
    :type next_frame: int
    :param channels: Channels, Set of properties that are affectedALL All Properties, All properties, including transforms, bendy bone shape, and custom properties.LOC Location, Location only.ROT Rotation, Rotation only.SIZE Scale, Scale only.BBONE Bendy Bone, Bendy Bone shape properties.CUSTOM Custom Properties, Custom properties. 
    :type channels: typing.Union[int, str]
    :param axis_lock: Axis Lock, Transform axis to restrict effects toFREE Free, All axes are affected.X X, Only X-axis transforms are affected.Y Y, Only Y-axis transforms are affected.Z Z, Only Z-axis transforms are affected. 
    :type axis_lock: typing.Union[int, str]
    '''

    pass


def relax_rest(percentage: float = 0.5,
               prev_frame: int = 0,
               next_frame: int = 0,
               channels: typing.Union[int, str] = 'ALL',
               axis_lock: typing.Union[int, str] = 'FREE'):
    '''Make the current pose more similar to the rest pose 

    :param percentage: Percentage, Weighting factor for which keyframe is favored more 
    :type percentage: float
    :param prev_frame: Previous Keyframe, Frame number of keyframe immediately before the current frame 
    :type prev_frame: int
    :param next_frame: Next Keyframe, Frame number of keyframe immediately after the current frame 
    :type next_frame: int
    :param channels: Channels, Set of properties that are affectedALL All Properties, All properties, including transforms, bendy bone shape, and custom properties.LOC Location, Location only.ROT Rotation, Rotation only.SIZE Scale, Scale only.BBONE Bendy Bone, Bendy Bone shape properties.CUSTOM Custom Properties, Custom properties. 
    :type channels: typing.Union[int, str]
    :param axis_lock: Axis Lock, Transform axis to restrict effects toFREE Free, All axes are affected.X X, Only X-axis transforms are affected.Y Y, Only Y-axis transforms are affected.Z Z, Only Z-axis transforms are affected. 
    :type axis_lock: typing.Union[int, str]
    '''

    pass


def reveal(select: bool = True):
    '''Reveal all bones hidden in Pose Mode 

    :param select: Select 
    :type select: bool
    '''

    pass


def rot_clear():
    '''Reset rotations of selected bones to their default values 

    '''

    pass


def rotation_mode_set(type: typing.Union[int, str] = 'QUATERNION'):
    '''Set the rotation representation used by selected bones 

    :param type: Rotation ModeQUATERNION Quaternion (WXYZ), No Gimbal Lock.XYZ XYZ Euler, XYZ Rotation Order - prone to Gimbal Lock (default).XZY XZY Euler, XZY Rotation Order - prone to Gimbal Lock.YXZ YXZ Euler, YXZ Rotation Order - prone to Gimbal Lock.YZX YZX Euler, YZX Rotation Order - prone to Gimbal Lock.ZXY ZXY Euler, ZXY Rotation Order - prone to Gimbal Lock.ZYX ZYX Euler, ZYX Rotation Order - prone to Gimbal Lock.AXIS_ANGLE Axis Angle, Axis Angle (W+XYZ), defines a rotation around some axis defined by 3D-Vector. 
    :type type: typing.Union[int, str]
    '''

    pass


def scale_clear():
    '''Reset scaling of selected bones to their default values 

    '''

    pass


def select_all(action: typing.Union[int, str] = 'TOGGLE'):
    '''Toggle selection status of all bones 

    :param action: Action, Selection action to executeTOGGLE Toggle, Toggle selection for all elements.SELECT Select, Select all elements.DESELECT Deselect, Deselect all elements.INVERT Invert, Invert selection of all elements. 
    :type action: typing.Union[int, str]
    '''

    pass


def select_constraint_target():
    '''Select bones used as targets for the currently selected bones 

    '''

    pass


def select_grouped(extend: bool = False,
                   type: typing.Union[int, str] = 'LAYER'):
    '''Select all visible bones grouped by similar properties 

    :param extend: Extend, Extend selection instead of deselecting everything first 
    :type extend: bool
    :param type: TypeLAYER Layer, Shared layers.GROUP Group, Shared group.KEYINGSET Keying Set, All bones affected by active Keying Set. 
    :type type: typing.Union[int, str]
    '''

    pass


def select_hierarchy(direction: typing.Union[int, str] = 'PARENT',
                     extend: bool = False):
    '''Select immediate parent/children of selected bones 

    :param direction: Direction 
    :type direction: typing.Union[int, str]
    :param extend: Extend, Extend the selection 
    :type extend: bool
    '''

    pass


def select_linked(extend: bool = False):
    '''Select bones related to selected ones by parent/child relationships 

    :param extend: Extend, Extend selection instead of deselecting everything first 
    :type extend: bool
    '''

    pass


def select_mirror(only_active: bool = False, extend: bool = False):
    '''Mirror the bone selection 

    :param only_active: Active Only, Only operate on the active bone 
    :type only_active: bool
    :param extend: Extend, Extend the selection 
    :type extend: bool
    '''

    pass


def select_parent():
    '''Select bones that are parents of the currently selected bones 

    '''

    pass


def transforms_clear():
    '''Reset location, rotation, and scaling of selected bones to their default values 

    '''

    pass


def user_transforms_clear(only_selected: bool = True):
    '''Reset pose on selected bones to keyframed state 

    :param only_selected: Only Selected, Only visible/selected bones 
    :type only_selected: bool
    '''

    pass


def visual_transform_apply():
    '''Apply final constrained position of pose bones to their transform 

    '''

    pass



import sys
import typing
import bpy

from . import units
from . import previews


def app_template_paths(subdir: str = None):
    '''Returns valid application template paths. 

    :param subdir: Optional subdir. 
    :type subdir: str
    :return:  app template paths. 
    '''

    pass


def blend_paths(absolute: bool = False,
                packed: bool = False,
                local: bool = False) -> list:
    '''Returns a list of paths to external files referenced by the loaded .blend file. 

    :param absolute: When true the paths returned are made absolute. 
    :type absolute: bool
    :param packed: When true skip file paths for packed data. 
    :type packed: bool
    :param local: When true skip linked library paths. 
    :type local: bool
    :return:  path list. 
    '''

    pass


def escape_identifier(string: str) -> str:
    '''Simple string escaping function used for animation paths. 

    :param string: text 
    :type string: str
    :return:  The escaped string. 
    '''

    pass


def execfile(filepath, mod=None):
    '''

    '''

    pass


def keyconfig_init():
    '''

    '''

    pass


def keyconfig_set(filepath, report=None):
    '''

    '''

    pass


def load_scripts(reload_scripts: bool = False, refresh_scripts: bool = False):
    '''Load scripts and run each modules register function. 

    :param reload_scripts: Causes all scripts to have their unregister method called before loading. 
    :type reload_scripts: bool
    :param refresh_scripts: only load scripts which are not already loaded as modules. 
    :type refresh_scripts: bool
    '''

    pass


def make_rna_paths(struct_name: str, prop_name: str, enum_name: str):
    '''Create RNA “paths” from given names. 

    :param struct_name: Name of a RNA struct (like e.g. “Scene”). 
    :type struct_name: str
    :param prop_name: Name of a RNA struct’s property. 
    :type prop_name: str
    :param enum_name: Name of a RNA enum identifier. 
    :type enum_name: str
    :return:  A triple of three “RNA paths” (most_complete_path, “struct.prop”, “struct.prop:’enum’”). If no enum_name is given, the third element will always be void. 
    '''

    pass


def manual_map():
    '''

    '''

    pass


def modules_from_path(path: str, loaded_modules: set) -> list:
    '''Load all modules in a path and return them as a list. 

    :param path: this path is scanned for scripts and packages. 
    :type path: str
    :param loaded_modules: already loaded module names, files matching these names will be ignored. 
    :type loaded_modules: set
    :return:  all loaded modules. 
    '''

    pass


def preset_find(name, preset_path, display_name=False, ext='.py'):
    '''

    '''

    pass


def preset_paths(subdir: str) -> list:
    '''Returns a list of paths for a specific preset. 

    :param subdir: preset subdirectory (must not be an absolute path). 
    :type subdir: str
    :return:  script paths. 
    '''

    pass


def refresh_script_paths():
    '''Run this after creating new script paths to update sys.path 

    '''

    pass


def register_class(cls):
    '''If the class has a register class method it will be called before registration. 

    '''

    pass


def register_classes_factory(classes):
    '''Utility function to create register and unregister functions which simply registers and unregisters a sequence of classes. 

    '''

    pass


def register_manual_map(manual_hook):
    '''

    '''

    pass


def register_submodule_factory(module_name: str, submodule_names: list):
    '''Utility function to create register and unregister functions which simply load submodules, calling their register & unregister functions. 

    :param module_name: The module name, typically __name__. 
    :type module_name: str
    :param submodule_names: List of submodule names to load and unload. 
    :type submodule_names: list
    :return:  register and unregister functions. 
    '''

    pass


def register_tool(tool_cls,
                  *,
                  after: 'bpy.context.collection' = None,
                  separator: bool = False,
                  group: bool = False):
    '''Register a tool in the toolbar. 

    :param tool: A tool subclass. 
    :type tool: 'bpy.types.WorkSpaceTool'
    :param space_type: Space type identifier. 
    :type space_type: str
    :param after: Optional identifiers this tool will be added after. 
    :type after: 'bpy.context.collection'
    :param separator: When true, add a separator before this tool. 
    :type separator: bool
    :param group: When true, add a new nested group of tools. 
    :type group: bool
    '''

    pass


def resource_path(type: str, major: int = 2, minor: str = "") -> str:
    '''Return the base path for storing system files. 

    :param type: string in [‘USER’, ‘LOCAL’, ‘SYSTEM’]. 
    :type type: str
    :param major: major version, defaults to current. 
    :type major: int
    :param minor: minor version, defaults to current. 
    :type minor: str
    :return:  the resource path (not necessarily existing). 
    '''

    pass


def script_path_pref():
    '''returns the user preference or None 

    '''

    pass


def script_path_user():
    '''returns the env var and falls back to home dir or None 

    '''

    pass


def script_paths(subdir: str = None,
                 user_pref: bool = True,
                 check_all: bool = False,
                 use_user=True) -> list:
    '''Returns a list of valid script paths. 

    :param subdir: Optional subdir. 
    :type subdir: str
    :param user_pref: Include the user preference script path. 
    :type user_pref: bool
    :param check_all: Include local, user and system paths rather just the paths blender uses. 
    :type check_all: bool
    :return:  script paths. 
    '''

    pass


def smpte_from_frame(frame: int, fps=None, fps_base=None) -> str:
    '''If fps and fps_base are not given the current scene is used. 

    :param frame: frame number. 
    :type frame: int
    :return:  the frame string. 
    '''

    pass


def smpte_from_seconds(time: typing.Union[int, float], fps=None,
                       fps_base=None) -> str:
    '''If fps and fps_base are not given the current scene is used. 

    :param time: time in seconds. 
    :type time: typing.Union[int, float]
    :return:  the frame string. 
    '''

    pass


def unregister_class(cls):
    '''If the class has an unregister class method it will be called before unregistering. 

    '''

    pass


def unregister_manual_map(manual_hook):
    '''

    '''

    pass


def unregister_tool(tool_cls):
    '''

    '''

    pass


def user_resource(resource_type, path='', create: bool = False) -> str:
    '''Return a user resource path (normally from the users home directory). 

    :param type: Resource type in [‘DATAFILES’, ‘CONFIG’, ‘SCRIPTS’, ‘AUTOSAVE’]. 
    :type type: str
    :param subdir: Optional subdirectory. 
    :type subdir: str
    :param create: Treat the path as a directory and create it if its not existing. 
    :type create: bool
    :return:  a path. 
    '''

    pass



import sys
import typing
import bpy


class ImagePreviewCollection:
    '''This is a subclass of Python’s built-in dict type, used to store multiple image previews. '''

    def clear(self, ):
        '''Clear all previews. 

        '''
        pass

    def close(self, ):
        '''Close the collection and clear all previews. 

        '''
        pass

    def load(self,
             name: str,
             filepath: str,
             filetype: str,
             force_reload: bool = False) -> 'bpy.types.ImagePreview':
        '''Generate a new preview from given file path, or return existing one matching name. 

        :param name: The name (unique id) identifying the preview. 
        :type name: str
        :param filepath: The file path to generate the preview from. 
        :type filepath: str
        :param filetype: The type of file, needed to generate the preview in [‘IMAGE’, ‘MOVIE’, ‘BLEND’, ‘FONT’]. 
        :type filetype: str
        :param force_reload: If True, force running thumbnail manager even if preview already exists in cache. 
        :type force_reload: bool
        :rtype: 'bpy.types.ImagePreview'
        :return:  The Preview matching given name, or a new empty one. 
        '''
        pass

    def new(self, name: str) -> 'bpy.types.ImagePreview':
        '''Generate a new empty preview, or return existing one matching name. 

        :param name: The name (unique id) identifying the preview. 
        :type name: str
        :rtype: 'bpy.types.ImagePreview'
        :return:  The Preview matching given name, or a new empty one. 
        '''
        pass


def new() -> 'ImagePreviewCollection':
    '''

    :return:  a new preview collection. 
    '''

    pass


def remove(pcoll: 'ImagePreviewCollection'):
    '''Remove the specified previews collection. 

    :param pcoll: Preview collection to close. 
    :type pcoll: 'ImagePreviewCollection'
    '''

    pass



import sys
import typing
import bpy


def add_simple_uvs():
    '''Add cube map uvs on mesh 

    '''

    pass


def add_texture_paint_slot(type: typing.Union[int, str] = 'BASE_COLOR',
                           name: str = "Untitled",
                           width: int = 1024,
                           height: int = 1024,
                           color: float = (0.0, 0.0, 0.0, 1.0),
                           alpha: bool = True,
                           generated_type: typing.Union[int, str] = 'BLANK',
                           float: bool = False):
    '''Add a texture paint slot 

    :param type: Type, Merge method to use 
    :type type: typing.Union[int, str]
    :param name: Name, Image data-block name 
    :type name: str
    :param width: Width, Image width 
    :type width: int
    :param height: Height, Image height 
    :type height: int
    :param color: Color, Default fill color 
    :type color: float
    :param alpha: Alpha, Create an image with an alpha channel 
    :type alpha: bool
    :param generated_type: Generated Type, Fill the image with a grid for UV map testingBLANK Blank, Generate a blank image.UV_GRID UV Grid, Generated grid to test UV mappings.COLOR_GRID Color Grid, Generated improved UV grid to test UV mappings. 
    :type generated_type: typing.Union[int, str]
    :param float: 32 bit Float, Create image with 32 bit floating point bit depth 
    :type float: bool
    '''

    pass


def brush_colors_flip():
    '''Toggle foreground and background brush colors 

    '''

    pass


def brush_select(sculpt_tool: typing.Union[int, str] = 'DRAW',
                 vertex_tool: typing.Union[int, str] = 'DRAW',
                 weight_tool: typing.Union[int, str] = 'DRAW',
                 image_tool: typing.Union[int, str] = 'DRAW',
                 gpencil_tool: typing.Union[int, str] = 'DRAW',
                 toggle: bool = False,
                 create_missing: bool = False):
    '''Select a paint mode’s brush by tool type 

    :param sculpt_tool: sculpt_tool 
    :type sculpt_tool: typing.Union[int, str]
    :param vertex_tool: vertex_tool 
    :type vertex_tool: typing.Union[int, str]
    :param weight_tool: weight_tool 
    :type weight_tool: typing.Union[int, str]
    :param image_tool: image_tool 
    :type image_tool: typing.Union[int, str]
    :param gpencil_tool: gpencil_toolDRAW Draw, The brush is of type used for drawing strokes.FILL Fill, The brush is of type used for filling areas.ERASE Erase, The brush is used for erasing strokes. 
    :type gpencil_tool: typing.Union[int, str]
    :param toggle: Toggle, Toggle between two brushes rather than cycling 
    :type toggle: bool
    :param create_missing: Create Missing, If the requested brush type does not exist, create a new brush 
    :type create_missing: bool
    '''

    pass


def face_select_all(action: typing.Union[int, str] = 'TOGGLE'):
    '''Change selection for all faces 

    :param action: Action, Selection action to executeTOGGLE Toggle, Toggle selection for all elements.SELECT Select, Select all elements.DESELECT Deselect, Deselect all elements.INVERT Invert, Invert selection of all elements. 
    :type action: typing.Union[int, str]
    '''

    pass


def face_select_hide(unselected: bool = False):
    '''Hide selected faces 

    :param unselected: Unselected, Hide unselected rather than selected objects 
    :type unselected: bool
    '''

    pass


def face_select_linked():
    '''Select linked faces 

    '''

    pass


def face_select_linked_pick(deselect: bool = False):
    '''Select linked faces under the cursor 

    :param deselect: Deselect, Deselect rather than select items 
    :type deselect: bool
    '''

    pass


def face_select_reveal(select: bool = True):
    '''Reveal hidden faces 

    :param select: Select 
    :type select: bool
    '''

    pass


def grab_clone(delta: float = (0.0, 0.0)):
    '''Move the clone source image 

    :param delta: Delta, Delta offset of clone image in 0.0..1.0 coordinates 
    :type delta: float
    '''

    pass


def hide_show(action: typing.Union[int, str] = 'HIDE',
              area: typing.Union[int, str] = 'INSIDE',
              xmin: int = 0,
              xmax: int = 0,
              ymin: int = 0,
              ymax: int = 0,
              wait_for_input: bool = True):
    '''Hide/show some vertices 

    :param action: Action, Whether to hide or show verticesHIDE Hide, Hide vertices.SHOW Show, Show vertices. 
    :type action: typing.Union[int, str]
    :param area: Area, Which vertices to hide or showOUTSIDE Outside, Hide or show vertices outside the selection.INSIDE Inside, Hide or show vertices inside the selection.ALL All, Hide or show all vertices.MASKED Masked, Hide or show vertices that are masked (minimum mask value of 0.5). 
    :type area: typing.Union[int, str]
    :param xmin: X Min 
    :type xmin: int
    :param xmax: X Max 
    :type xmax: int
    :param ymin: Y Min 
    :type ymin: int
    :param ymax: Y Max 
    :type ymax: int
    :param wait_for_input: Wait for Input 
    :type wait_for_input: bool
    '''

    pass


def image_from_view(filepath: str = ""):
    '''Make an image from biggest 3D view for re-projection 

    :param filepath: File Path, Name of the file 
    :type filepath: str
    '''

    pass


def image_paint(stroke: typing.List['bpy.types.OperatorStrokeElement'] = None,
                mode: typing.Union[int, str] = 'NORMAL'):
    '''Paint a stroke into the image 

    :param stroke: Stroke 
    :type stroke: typing.List['bpy.types.OperatorStrokeElement']
    :param mode: Stroke Mode, Action taken when a paint stroke is madeNORMAL Regular, Apply brush normally.INVERT Invert, Invert action of brush for duration of stroke.SMOOTH Smooth, Switch brush to smooth mode for duration of stroke. 
    :type mode: typing.Union[int, str]
    '''

    pass


def mask_flood_fill(mode: typing.Union[int, str] = 'VALUE',
                    value: float = 0.0):
    '''Fill the whole mask with a given value, or invert its values 

    :param mode: ModeVALUE Value, Set mask to the level specified by the ‘value’ property.VALUE_INVERSE Value Inverted, Set mask to the level specified by the inverted ‘value’ property.INVERT Invert, Invert the mask. 
    :type mode: typing.Union[int, str]
    :param value: Value, Mask level to use when mode is ‘Value’; zero means no masking and one is fully masked 
    :type value: float
    '''

    pass


def mask_lasso_gesture(path: typing.List['bpy.types.OperatorMousePath'] = None,
                       mode: typing.Union[int, str] = 'VALUE',
                       value: float = 1.0):
    '''Add mask within the lasso as you move the brush 

    :param path: Path 
    :type path: typing.List['bpy.types.OperatorMousePath']
    :param mode: ModeVALUE Value, Set mask to the level specified by the ‘value’ property.VALUE_INVERSE Value Inverted, Set mask to the level specified by the inverted ‘value’ property.INVERT Invert, Invert the mask. 
    :type mode: typing.Union[int, str]
    :param value: Value, Mask level to use when mode is ‘Value’; zero means no masking and one is fully masked 
    :type value: float
    '''

    pass


def project_image(image: typing.Union[int, str] = ''):
    '''Project an edited render from the active camera back onto the object 

    :param image: Image 
    :type image: typing.Union[int, str]
    '''

    pass


def sample_color(location: int = (0, 0),
                 merged: bool = False,
                 palette: bool = False):
    '''Use the mouse to sample a color in the image 

    :param location: Location 
    :type location: int
    :param merged: Sample Merged, Sample the output display color 
    :type merged: bool
    :param palette: Add to Palette 
    :type palette: bool
    '''

    pass


def texture_paint_toggle():
    '''Toggle texture paint mode in 3D view 

    '''

    pass


def vert_select_all(action: typing.Union[int, str] = 'TOGGLE'):
    '''Change selection for all vertices 

    :param action: Action, Selection action to executeTOGGLE Toggle, Toggle selection for all elements.SELECT Select, Select all elements.DESELECT Deselect, Deselect all elements.INVERT Invert, Invert selection of all elements. 
    :type action: typing.Union[int, str]
    '''

    pass


def vert_select_ungrouped(extend: bool = False):
    '''Select vertices without a group 

    :param extend: Extend, Extend the selection 
    :type extend: bool
    '''

    pass


def vertex_color_brightness_contrast(brightness: float = 0.0,
                                     contrast: float = 0.0):
    '''Adjust vertex color brightness/contrast 

    :param brightness: Brightness 
    :type brightness: float
    :param contrast: Contrast 
    :type contrast: float
    '''

    pass


def vertex_color_dirt(blur_strength: float = 1.0,
                      blur_iterations: int = 1,
                      clean_angle: float = 3.14159,
                      dirt_angle: float = 0.0,
                      dirt_only: bool = False):
    '''Undocumented contribute <https://developer.blender.org/T51061> 

    :param blur_strength: Blur Strength, Blur strength per iteration 
    :type blur_strength: float
    :param blur_iterations: Blur Iterations, Number of times to blur the colors (higher blurs more) 
    :type blur_iterations: int
    :param clean_angle: Highlight Angle, Less than 90 limits the angle used in the tonal range 
    :type clean_angle: float
    :param dirt_angle: Dirt Angle, Less than 90 limits the angle used in the tonal range 
    :type dirt_angle: float
    :param dirt_only: Dirt Only, Don’t calculate cleans for convex areas 
    :type dirt_only: bool
    '''

    pass


def vertex_color_from_weight():
    '''Convert active weight into gray scale vertex colors 

    '''

    pass


def vertex_color_hsv(h: float = 0.5, s: float = 1.0, v: float = 1.0):
    '''Adjust vertex color HSV values 

    :param h: Hue 
    :type h: float
    :param s: Saturation 
    :type s: float
    :param v: Value 
    :type v: float
    '''

    pass


def vertex_color_invert():
    '''Invert RGB values 

    '''

    pass


def vertex_color_levels(offset: float = 0.0, gain: float = 1.0):
    '''Adjust levels of vertex colors 

    :param offset: Offset, Value to add to colors 
    :type offset: float
    :param gain: Gain, Value to multiply colors by 
    :type gain: float
    '''

    pass


def vertex_color_set():
    '''Fill the active vertex color layer with the current paint color 

    '''

    pass


def vertex_color_smooth():
    '''Smooth colors across vertices 

    '''

    pass


def vertex_paint(stroke: typing.List['bpy.types.OperatorStrokeElement'] = None,
                 mode: typing.Union[int, str] = 'NORMAL'):
    '''Paint a stroke in the active vertex color layer 

    :param stroke: Stroke 
    :type stroke: typing.List['bpy.types.OperatorStrokeElement']
    :param mode: Stroke Mode, Action taken when a paint stroke is madeNORMAL Regular, Apply brush normally.INVERT Invert, Invert action of brush for duration of stroke.SMOOTH Smooth, Switch brush to smooth mode for duration of stroke. 
    :type mode: typing.Union[int, str]
    '''

    pass


def vertex_paint_toggle():
    '''Toggle the vertex paint mode in 3D view 

    '''

    pass


def weight_from_bones(type: typing.Union[int, str] = 'AUTOMATIC'):
    '''Set the weights of the groups matching the attached armature’s selected bones, using the distance between the vertices and the bones 

    :param type: Type, Method to use for assigning weightsAUTOMATIC Automatic, Automatic weights from bones.ENVELOPES From Envelopes, Weights from envelopes with user defined radius. 
    :type type: typing.Union[int, str]
    '''

    pass


def weight_gradient(type: typing.Union[int, str] = 'LINEAR',
                    xstart: int = 0,
                    xend: int = 0,
                    ystart: int = 0,
                    yend: int = 0,
                    cursor: int = 1002):
    '''Draw a line to apply a weight gradient to selected vertices 

    :param type: Type 
    :type type: typing.Union[int, str]
    :param xstart: X Start 
    :type xstart: int
    :param xend: X End 
    :type xend: int
    :param ystart: Y Start 
    :type ystart: int
    :param yend: Y End 
    :type yend: int
    :param cursor: Cursor, Mouse cursor style to use during the modal operator 
    :type cursor: int
    '''

    pass


def weight_paint(stroke: typing.List['bpy.types.OperatorStrokeElement'] = None,
                 mode: typing.Union[int, str] = 'NORMAL'):
    '''Paint a stroke in the current vertex group’s weights 

    :param stroke: Stroke 
    :type stroke: typing.List['bpy.types.OperatorStrokeElement']
    :param mode: Stroke Mode, Action taken when a paint stroke is madeNORMAL Regular, Apply brush normally.INVERT Invert, Invert action of brush for duration of stroke.SMOOTH Smooth, Switch brush to smooth mode for duration of stroke. 
    :type mode: typing.Union[int, str]
    '''

    pass


def weight_paint_toggle():
    '''Toggle weight paint mode in 3D view 

    '''

    pass


def weight_sample():
    '''Use the mouse to sample a weight in the 3D view 

    '''

    pass


def weight_sample_group(group: typing.Union[int, str] = 'DEFAULT'):
    '''Select one of the vertex groups available under current mouse position 

    :param group: Keying Set, The Keying Set to use 
    :type group: typing.Union[int, str]
    '''

    pass


def weight_set():
    '''Fill the active vertex group with the current paint weight 

    '''

    pass
